:py:mod:`piel.models.frequency.electro_optic.ideal`
===================================================

.. py:module:: piel.models.frequency.electro_optic.ideal


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.electro_optic.ideal.ideal_active_mzi2x2_2x2



.. py:function:: ideal_active_mzi2x2_2x2()
